@@ -1,14 +1,13 @@
 package Dist::Zilla::PluginBundle::IDOPEREL;
 
 BEGIN {
-	use version 0.77; our $VERSION = version->declare("v0.600.1");
+	use version 0.77; our $VERSION = version->declare("v0.600.2");
 }
 
 use Moose;
-use Moose::Autobox;
 use namespace::autoclean;
 
-with 'Dist::Zilla::Role::PluginBundle';
+with 'Dist::Zilla::Role::PluginBundle::Easy';
 
 # ABSTRACT: IDOPEREL's plugin bundle for Dist::Zilla.
 
@@ -35,7 +34,7 @@ Dist::Zilla::PluginBundle::IDOPEREL - IDOPEREL's plugin bundle for Dist::Zilla.
 
 =head1 VERSION
 
-version v0.600.1
+version v0.600.2
 
 =head1 SYNOPSIS
 
@@ -75,52 +74,34 @@ This bundle provides the following plugins and bundles:
 
 =head1 INTERNAL METHODS
 
-=head2 bundle_config
+=head2 configure
 
 =cut
 
-sub bundle_config {
-	my ($self, $section) = @_;
-	my $class = ref($self) || $self;
+sub configure {
+	my $self = shift;
 
-	my $arg = $section->{payload};
+	$self->add_bundle(Filter => {
+		-bundle => '@Classic',
+		-remove => [qw/Readme PkgVersion/],
+	});
 
-	my @plugins = Dist::Zilla::PluginBundle::Filter->bundle_config(
-		{
-			name    => "$class/Classic",
-			payload => {
-				bundle => '@Classic',
-				remove => [qw/Readme/],
-			}
-		}
+	$self->add_plugins(
+		'VersionFromModule',
+		[ 'AutoPrereqs' => { skip => $self->payload->{auto_prereqs_skip} } ],
+		[ 'Prereqs' => 'version' => { -phase => 'configure', -type => 'requires', 'version' => 0.77 } ],
+		'MetaJSON',
+		'MinimumPerl',
+		'NextRelease',
+		'ReadmeFromPod',
+		'InstallGuide',
+		'CheckChangesHasContent',
+		'DistManifestTests',
+		'TestRelease',
+		'Signature'
 	);
 
-	# params
-
-	my $prefix = 'Dist::Zilla::Plugin::';
-	my @extra = map { [ "$class/$prefix$_->[0]" => "$prefix$_->[0]" => $_->[1] ] } (
-		[ VersionFromModule		=> {} ],
-		[ AutoPrereqs			=> { skip  => $arg->{auto_prereqs_skip} } ],
-		[ Prereqs			=> { version => 0.77 } ],
-		[ MetaJSON			=> {} ],
-		[ MinimumPerl			=> {} ],
-		[ NextRelease			=> {} ],
-		[ ReadmeFromPod			=> {} ],
-		[ InstallGuide			=> {} ],
-		[ CheckChangesHasContent	=> {} ],
-		[ DistManifestTests		=> {} ],
-		[ TestRelease			=> {} ],
-		[ Signature			=> {} ],
-	);
-
-	push (@plugins, @extra);
-
-	# add git plugins
-	push (@plugins,	Dist::Zilla::PluginBundle::Git->bundle_config({ name => "$section->{name}/Git",	payload => {} }));
-
-	eval "require $_->[1]; 1;" or die for @plugins; ## no critic Carp
-
-	return @plugins;
+	$self->add_bundle('Git');
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -162,13 +143,9 @@ L<http://search.cpan.org/dist/Dist-Zilla-PluginBundle-IDOPEREL/>
 
 =back
 
-=head1 ACKNOWLEDGMENTS
-
-Based on L<Dist::Zilla::PluginBundle::PDONELAN> by Patrick Donelan.
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Ido Perlmuter.
+Copyright 2010-2011 Ido Perlmuter.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
